#PBS -S /bin/ksh          # ligne obligatoire specifiant le shell: ksh ou csh
#PBS -N TEST        # nom de la requete (defaut : nom du fichier)
#PBS -j o                 # concatene la sortie standard avec l erreur standard
#PBS -l cputim_prc=03:55:00  # temps max (HH:MM:SS)/ process 
#PBS -l cputim_job=03:59:00  # temps max (HH:MM:SS)/job
#PBS -l memsz_job=6gb        # memoire max /job




###############################################################################
#  #PBS -S /bin/ksh
#  #PBS -N Senegal
#  #PBS -j oe
#  #PBS -q day
###############################################################################


reseau_local=0
veget=1
stopsim=198912
ok_guide=n   # y/n guidage ou non
climato=1

if [ $reseau_local = 1 ] ; then
   MAINDIR=/d0/hourdin/$simul
   SIMUDIR=$MAINDIR/AMIP
   NCEPDIR=$MAINDIR
   LIMITDIR=$MAINDIR
   DEFDIR=$SIMUDIR/DEF
   GET='ln -s '
   PUT='mv '
   workdir=$SIMUDIR

else
   MAINDIR=NIMPORTEQUOI
   SIMUDIR=$MAINDIR/$simul
   NCEPDIR=$MAINDIR
   LIMITDIR=$SIMUDIR
   DEFDIR=~/$SIMUDIR/DEF
   GET='mfget '
   PUT='mfput '
   workdir=$tmpdir
# Dans le cas du reseau non local, on suppose qu'on a le meme repertoire
# $MAIDIR sur le home de la machine de stokage et sur le home de la
# machine de calcul. Sur le home de la machine de calcul, on ne
# conservera que les fichiers .def et le script de lancement.

fi

cd $workdir

echo '##################################################################'
echo 'Gestion des mois et annees'
echo '##################################################################'

if [ $month = 12 ] ; then
   nextmonth=1
   nextyear=`expr $year + 1`
else
   nextmonth=`expr $month + 1`
   nextyear=$year
fi

if [ `echo $nextmonth | wc -m` = 2  ] ; then
nextmonth=0$nextmonth
fi

ym=$year$month
next=$nextyear$nextmonth
echo mois ancien  : $ym
echo mois nouveau : $next


echo '#################################################################'
echo 'Modification de run.def et gcm.def pour prendre en compte la duree du'
echo 'du mois en question.'
echo 'le dayref est modifie pour tricher avec le calendrier (ecrit pour'
echo 'une annee de 260 jours dans le modele).'
echo 'On passe donc comme jour de reference le numero du jour du mois dans'
echo 'une annee en 360 jours.'
echo '#################################################################'


if [ "$ok_guide" = "y" ] ; then
   # longueur du mois vrai
   if [ $month = 04 -o $month = 06 -o $month = 09 -o $month = 11 ] ; then
      nday=30
   elif [ $month = 02 ] ; then
      if [ $year = 2000 ] ; then
          nday=29
      else
          nday=28
      fi
   else
      nday=31
   fi
else
    nday=30
fi


dayref=`echo $month | awk ' { print ( $1 - 1 ) * 30 + 1 } '`

echo Longueur du mois $nday
echo Jour de reference $dayref


####################################################################
# On va chercher les fichiers nécessaires à la simulation
####################################################################

echo DEFDIR $DEFDIR
echo SIMUDIR $SIMUDIR
echo simul $simul
cp -f $DEFDIR/*def $DEFDIR/*sed .


sed -e 's/ok_guide=.*.$/ok_guide='$ok_guide'/' gcm.sed >| gcm.def

sed -e 's/nday=.*.$/nday='$nday'/' -e 's/dayref=.*.$/dayref='${dayref}'/' run.sed >| run.def


sed -e 's/ecrit_mth=.*.$/ecrit_mth='$nday'/' physiq.sed >| physiq.def
# \cp physiq.sed physiq.def


for file in gcm physiq run ; do
echo '####################################################################'
echo diff $file.sed $file.def
diff $file.sed $file.def
echo '####################################################################'
done

\rm start.nc startphy.nc limit.nc

${GET} $SIMUDIR/start.$ym.nc start.nc
${GET} $SIMUDIR/startphy.$ym.nc startphy.nc
if [ $climato = 1 ] ; then
   ${GET} $LIMITDIR/limit.nc limit.nc
else
   ${GET} $LIMITDIR/limit$year.nc limit.nc
fi
${GET} $SIMUDIR/gcm.e gcm.e


if [ $veget = 1 ] ; then ${GET} $SIMUDIR/start_sech.$ym.nc start_sech.nc ; fi


echo '#################################################################'
echo     Repertoire contenant les fichiers de reanalyses
echo '#################################################################'

if [ "$ok_guide" = "y" ] ; then
   \rm u.nc v.nc ps.nc T.nc hur.nc tmp.jnl ferret.jnl
   if [ -f u.nc ] ; then
      echo PROBLEME D EFFACEMENT DES FICHIERS DE REANALYSES
      exit
   fi
   NCEP="$GET $NCEPDIR/$ym"
   ${NCEP}u.nc u.nc
   ${NCEP}v.nc v.nc
   ${NCEP}T.nc T.nc
   ${NCEP}hur.nc hur.nc
   ${NCEP}ps.nc ps.nc
   echo Fin du rapatriement des fichiers de guidage
fi

echo '##################################################################'
echo  liste des fichiers avant le lancement de la simulation
echo '##################################################################'
      ls -lrt


echo '##################################################################'
echo  Lancement de la simulation
echo '##################################################################'

time ./gcm.e > listing

${PUT} listing ${SIMUDIR}/list$ym
rm sechiba_out.nc

echo '##################################################################'
echo     sauvegarde des fichiers de sortie
echo '##################################################################'

${PUT} histmth.nc ${SIMUDIR}/histmth.$ym.nc
${PUT} histday.nc ${SIMUDIR}/histday.$ym.nc
${PUT} histhf.nc ${SIMUDIR}/histhf.$ym.nc

if [ ! -f restartphy.nc ] ; then
echo PROBLEME PAS DE FICHIER RESTARTPHY
exit
fi

${PUT} restart.nc ${SIMUDIR}/start.$next.nc
${PUT} restartphy.nc ${SIMUDIR}/startphy.$next.nc

if [ $veget = 1 ] ; then ${PUT} restart_sech.nc ${SIMUDIR}/start_sech.$next.nc ; fi

if [ $next =  $stopsim ] ; then
exit
fi

echo '##################################################################'
echo Lancement de la simulation suivante pour le mois $nextyear $nextmonth
echo '##################################################################'
cd  ~/$SIMUDIR/

qsub -v year=$nextyear,month=$nextmonth,simul=$simul enchaine.x > out.$next &
